Index: uspace/srv/devman/devman.c
===================================================================
--- uspace/srv/devman/devman.c	(revision 3843ecb7d7c7992f743d7917e8f23cddd7c7b5c9)
+++ uspace/srv/devman/devman.c	(revision a78fa2a9d35d4b71830ba7c047cb36f2e14a33c7)
@@ -503,13 +503,27 @@
 {
 	printf(NAME ": add_device\n");
-
-	ipcarg_t ret;
-	ipcarg_t rc = async_req_1_1(phone, DRIVER_ADD_DEVICE, node->handle, &ret);
-	if (rc != EOK) {
+	
+	ipcarg_t rc;
+	ipc_call_t answer;
+	
+	// send the device to the driver
+	aid_t req = async_send_1(phone, DRIVER_ADD_DEVICE, node->handle, &answer);
+	
+	// send the device's name to the driver
+	rc = async_data_write_start(phone, node->name, str_size(node->name) + 1);
+    if (rc != EOK) {
 		// TODO handle error
-		return;
-	}
-	
-	// TODO inspect return value (ret) to find out whether the device was successfully probed and added
+    }
+	
+	// wait for answer from the driver
+	async_wait_for(req, &rc);
+	switch(rc) {
+		// TODO inspect return value to find out whether the device was successfully probed and added
+	case EOK:
+	case ENOENT:
+		
+		break;
+		
+	}
 	
 	return;
